var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { Flex, Img } from 'honorable';
import PropTypes from 'prop-types';
import { forwardRef } from 'react';
import last from 'lodash/last';
import { styledTheme as theme } from '../theme';
import { useFillLevel } from './contexts/FillLevelContext';
const propTypes = {
    size: PropTypes.oneOf(['xxsmall', 'xsmall', 'small', 'medium', 'large', 'xlarge']),
    spacing: PropTypes.oneOf(['none', 'padding']),
    hue: PropTypes.oneOf(['default', 'lighter', 'lightest']),
    clickable: PropTypes.bool,
    url: PropTypes.string,
    alt: PropTypes.string,
};
const parentFillLevelToHue = {
    0: 'default',
    1: 'lighter',
    2: 'lightest',
    3: 'lightest',
};
const sizeToWidth = {
    xxsmall: 32,
    xsmall: 40,
    small: 64,
    medium: 96,
    large: 140,
    xlarge: 160,
};
const sizeToIconWidth = {
    xxsmall: 16,
    xsmall: 24,
    small: 48,
    medium: 64,
    large: 76,
    xlarge: 96,
};
const hueToColor = {
    default: 'fill-one',
    lighter: 'fill-two',
    lightest: 'fill-three',
};
const hueToBorderColor = {
    default: 'border',
    lighter: 'border-fill-two',
    lightest: 'border-fill-three',
};
const sizeToFont = {
    xsmall: theme.partials.text.body2Bold,
    small: theme.partials.text.subtitle2,
    medium: theme.partials.text.subtitle1,
    large: theme.partials.text.title2,
    xlarge: theme.partials.text.title2,
};
export function toInitials(name) {
    let initials = name
        .trim()
        .split(' ')
        .map(n => n.charAt(0).toUpperCase());
    if (initials.length > 2) {
        initials = [initials[0], last(initials)];
    }
    return initials.join('');
}
function AppIconRef(_a, ref) {
    var { size = 'medium', spacing = 'padding', hue, clickable = false, url, alt, name, initials, onClose } = _a, props = __rest(_a, ["size", "spacing", "hue", "clickable", "url", "alt", "name", "initials", "onClose"]);
    const parentFillLevel = useFillLevel();
    hue = hue || parentFillLevelToHue[parentFillLevel];
    const boxSize = sizeToWidth[size];
    const iconSize = spacing === 'padding' ? sizeToIconWidth[size] : sizeToWidth[size] + 1;
    const color = hueToColor[hue];
    const borderColor = hueToBorderColor[hue];
    const hasBorder = spacing === 'padding';
    return (_jsx(Flex, Object.assign({ backgroundColor: color, borderRadius: "medium", border: hasBorder ? '1px solid border' : 'none', borderColor: borderColor, width: boxSize, height: boxSize, minWidth: boxSize, minHeight: boxSize, align: "center", justify: "center", cursor: clickable ? 'pointer' : 'auto', overflow: "hidden", _hover: clickable ? { backgroundColor: borderColor } : null, onClick: clickable ? onClose : null }, { children: url ? (_jsx(Img, Object.assign({ ref: ref, src: url, alt: alt, width: iconSize, height: iconSize }, props))) : (_jsx(Flex, Object.assign({ width: "100%", height: "100%", alignItems: "center", justifyContent: "center", userSelect: "none", textTransform: "uppercase" }, sizeToFont[size], { children: initials || (name ? toInitials(name) : '') }))) })));
}
const AppIcon = forwardRef(AppIconRef);
AppIcon.propTypes = propTypes;
export default AppIcon;
//# sourceMappingURL=AppIcon.js.map