var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useMemo, } from 'react';
import { Flex, Span, } from 'honorable';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { FillLevelProvider } from './contexts/FillLevelContext';
import ErrorIcon from './icons/ErrorIcon';
import CloseIcon from './icons/CloseIcon';
import InfoIcon from './icons/InfoIcon';
import WarningIcon from './icons/WarningIcon';
import CheckRoundedIcon from './icons/CheckRoundedIcon';
import IconFrame from './IconFrame';
const SEVERITIES = ['info', 'error', 'warning', 'success', 'danger'];
const DEFAULT_SEVERITY = 'success';
const severityToIconColorKey = {
    info: 'icon-info',
    error: 'icon-danger',
    danger: 'icon-danger',
    warning: 'icon-warning',
    success: 'icon-success',
};
const severityToBorderColorKey = {
    info: 'border-info',
    error: 'border-danger',
    danger: 'border-danger',
    warning: 'border-warning',
    success: 'border-success',
};
const severityToIcon = {
    info: InfoIcon,
    error: ErrorIcon,
    danger: ErrorIcon,
    warning: WarningIcon,
    success: CheckRoundedIcon,
};
const BannerOuter = styled.div(({ $borderColorKey, theme }) => ({
    display: 'inline-flex',
    align: 'flex-start',
    padding: theme.spacing.medium,
    backgroundColor: theme.colors['fill-three'],
    borderRadius: theme.borderRadiuses.medium,
    borderTop: `4px solid ${theme.colors[$borderColorKey]}`,
    maxWidth: 480,
}));
const BannerInner = styled.div(({ theme }) => ({
    display: 'flex',
    paddingTop: theme.spacing.xxsmall,
    alignItems: 'flex-start',
}));
const IconWrap = styled.div(_ => ({
    display: 'flex',
    paddingTop: 2,
    paddingBottom: 2,
}));
const Heading = styled.div(({ $bold, theme }) => (Object.assign(Object.assign(Object.assign({}, theme.partials.text.body1), ($bold ? theme.partials.text.bodyBold : {})), { color: theme.colors.text })));
const BannerAction = styled(Span)(({ theme }) => ({
    marginLeft: theme.spacing.small,
    '&, & a, & a:any-link': Object.assign(Object.assign({}, theme.partials.text.inlineLink), theme.partials.text.bodyBold),
}));
const Content = styled.p(({ $hasHeading: $heading, theme }) => (Object.assign(Object.assign({}, theme.partials.text.body2LooseLineHeight), { marginTop: $heading ? theme.spacing.xxsmall : theme.spacing.xxxsmall, color: theme.colors['text-light'], '& a, & a:any-link': Object.assign({}, theme.partials.text.inlineLink) })));
const CloseButton = styled(IconFrame).attrs({
    size: 'medium',
    clickable: true,
    icon: _jsx(CloseIcon, {}),
})(({ theme }) => ({
    marginLeft: theme.spacing.medium,
}));
function BannerRef(_a, ref) {
    var { heading, action, actionProps, children, severity = 'success', onClose } = _a, props = __rest(_a, ["heading", "action", "actionProps", "children", "severity", "onClose"]);
    severity = useMemo(() => {
        if (!severityToIcon[severity]) {
            console.warn(`Banner: Incorrect severity (${severity}) specified. Valid values are ${SEVERITIES.map(s => `"${s}"`).join(', ')}. Defaulting to "${DEFAULT_SEVERITY}".`);
            return DEFAULT_SEVERITY;
        }
        return severity;
    }, [severity]);
    const BannerIcon = severityToIcon[severity];
    const iconColorKey = severityToIconColorKey[severity];
    const borderColorKey = severityToBorderColorKey[severity];
    function handleClose() {
        if (typeof onClose === 'function') {
            onClose();
        }
    }
    const content = (_jsxs(BannerOuter, Object.assign({ ref: ref, "$borderColorKey": borderColorKey, as: Flex }, props, { children: [_jsxs(BannerInner, { children: [_jsx(IconWrap, { children: _jsx(BannerIcon, { size: 20, color: iconColorKey, marginRight: "medium" }) }), _jsxs("div", { children: [heading && (_jsx(Heading, Object.assign({ "$bold": !!children }, { children: [
                                    heading,
                                    action && (_jsx(BannerAction, Object.assign({}, actionProps, { children: action }))),
                                ] }))), children && _jsx(Content, Object.assign({ "$hasHeading": !!heading }, { children: children }))] })] }), _jsx(CloseButton, { onClick: handleClose })] })));
    return _jsx(FillLevelProvider, Object.assign({ value: 3 }, { children: content }));
}
const Banner = forwardRef(BannerRef);
Banner.propTypes = {
    severity: PropTypes.oneOf(SEVERITIES),
    onClose: PropTypes.func,
};
export default Banner;
//# sourceMappingURL=Banner.js.map