var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { createContext, forwardRef, useCallback, useContext, useEffect, useMemo, useRef, useState, } from 'react';
import PropTypes from 'prop-types';
import { Button, Div, Flex } from 'honorable';
import styled, { useTheme } from 'styled-components';
import useResizeObserver from '../hooks/useResizeObserver';
import CopyIcon from './icons/CopyIcon';
import Card from './Card';
import CheckIcon from './icons/CheckIcon';
import Highlight from './Highlight';
import { FillLevelProvider, toFillLevel, useFillLevel, } from './contexts/FillLevelContext';
import FileIcon from './icons/FileIcon';
import { TabList } from './TabList';
import { SubTab } from './SubTab';
import TabPanel from './TabPanel';
import { Select } from './Select';
import { ListBoxItem } from './ListBoxItem';
import DropdownArrowIcon from './icons/DropdownArrowIcon';
const propTypes = {
    language: PropTypes.string,
    showLineNumbers: PropTypes.bool,
    showHeader: PropTypes.bool,
};
const TabsContext = createContext({
    setTabInterface: () => { },
    tabInterface: 'tabs',
});
function CodeHeaderUnstyled(_a) {
    var { fillLevel } = _a, props = __rest(_a, ["fillLevel"]);
    return (_jsx(FillLevelProvider, Object.assign({ value: toFillLevel(fillLevel + 2) }, { children: _jsx("div", Object.assign({}, props)) })));
}
const CodeHeader = styled(CodeHeaderUnstyled)(({ $visuallyHidden = false, fillLevel, theme }) => (Object.assign({ minHeight: theme.spacing.xlarge + theme.spacing.xsmall * 2, padding: `${theme.spacing.xsmall}px ${theme.spacing.medium}px`, borderBottom: fillLevel >= 1 ? theme.borders['fill-three'] : theme.borders['fill-two'], backgroundColor: fillLevel >= 1 ? theme.colors['fill-three'] : theme.colors['fill-two'], display: 'flex', alignItems: 'center', justifyContent: 'space-between', gap: theme.spacing.medium, borderTopLeftRadius: theme.borderRadiuses.medium + 2, borderTopRightRadius: theme.borderRadiuses.medium + 2 }, ($visuallyHidden
    ? {
        pointerEvents: 'none',
        height: 0,
        opacity: 0,
        overflow: 'hidden',
        minHeight: 0,
        position: 'absolute',
        top: 0,
        right: 0,
        left: 0,
    }
    : {}))));
function CopyButtonBase({ copied, handleCopy, className, }) {
    return (_jsx(Button, Object.assign({ className: className, position: "absolute", floating: true, small: true, startIcon: copied ? _jsx(CheckIcon, {}) : _jsx(CopyIcon, {}), onClick: handleCopy }, { children: copied ? 'Copied' : 'Copy' })));
}
const CopyButton = styled(CopyButtonBase)(({ verticallyCenter, theme }) => ({
    position: 'absolute',
    right: theme.spacing.medium,
    top: verticallyCenter ? '50%' : theme.spacing.medium,
    transform: verticallyCenter ? 'translateY(-50%)' : 'none',
    boxShadow: theme.boxShadows.slight,
}));
const TitleArea = styled.div(({ $shrinkable, theme }) => (Object.assign(Object.assign({ display: 'flex', flexShrink: $shrinkable ? 1 : 0, flexGrow: 1, gap: theme.spacing.xsmall }, theme.partials.text.overline), { color: 'text-light' })));
const tabsWrapMargin = 5;
const TabsWrap = styled.div(({ $isDisabled, theme: _ }) => (Object.assign({ flexShrink: 1, overflow: 'hidden', margin: -tabsWrapMargin, padding: tabsWrapMargin }, ($isDisabled ? { opacity: 0.0, height: 0 } : {}))));
const TabsDropdownButton = styled(forwardRef((props, ref) => {
    const fillLevel = useFillLevel();
    const theme = useTheme();
    return (_jsx(Button, Object.assign({ ref: ref, small: true, tertiary: true, endIcon: _jsx(DropdownArrowIcon, { className: "dropdownIcon" }) }, {
        '&, &:hover, &:focus, &:focus-visible': {
            backgroundColor: theme.colors[`fill-${fillLevel > 2 ? 'three' : 'two'}-selected`],
        },
    }, props)));
}))(({ isOpen = false, theme }) => ({
    '.dropdownIcon': {
        transform: isOpen ? 'scaleY(-1)' : 'scaleY(1)',
        transition: 'transform 0.1s ease',
    },
    backgroundColor: theme.colors['fill-one'],
}));
function CodeTabs() {
    const { tabInterface, setTabInterface, tabStateRef, tabs, selectedKey, onSelectionChange, } = useContext(TabsContext);
    const tabsRef = useRef();
    const tabsWrapRef = useRef();
    const tabListStateProps = {
        keyboardActivation: 'manual',
        orientation: 'horizontal',
        selectedKey,
        onSelectionChange,
        isDisabled: tabInterface !== 'tabs',
    };
    useResizeObserver(tabsRef, useCallback(() => {
        var _a, _b;
        const scrollWidth = (_a = tabsRef === null || tabsRef === void 0 ? void 0 : tabsRef.current) === null || _a === void 0 ? void 0 : _a.scrollWidth;
        const clientWidth = (_b = tabsRef === null || tabsRef === void 0 ? void 0 : tabsRef.current) === null || _b === void 0 ? void 0 : _b.clientWidth;
        if (typeof scrollWidth === 'number' && typeof clientWidth === 'number') {
            if (clientWidth - scrollWidth < 0) {
                setTabInterface('dropdown');
            }
            else {
                setTabInterface('tabs');
            }
        }
    }, [setTabInterface]));
    return (_jsx(TabsWrap, Object.assign({ ref: tabsWrapRef, "$isDisabled": tabListStateProps.isDisabled }, { children: _jsx(TabList, Object.assign({ className: "my-tab-list", stateRef: tabStateRef, stateProps: tabListStateProps, ref: tabsRef, style: !tabInterface ? { opacity: 0 } : undefined }, { children: tabs.map(tab => {
                if (typeof tab.content !== 'string') {
                    throw new Error('Code component expects a string for tabs[].content');
                }
                return (_jsx(SubTab, Object.assign({ size: "small", textValue: tab.label || tab.language }, { children: tab.label || tab.language }), tab.key));
            }) })) })));
}
function CodeSelectUnstyled({ className }) {
    const { tabs, selectedKey, onSelectionChange } = useContext(TabsContext);
    const selectedTab = tabs.find(tab => tab.key === selectedKey) || tabs[0];
    return (_jsx("div", Object.assign({ className: className }, { children: _jsx(Select, Object.assign({ selectedKey: selectedKey, onSelectionChange: key => {
                onSelectionChange(key);
            }, width: "max-content", placement: "right", triggerButton: _jsxs(TabsDropdownButton, { children: [selectedTab.label, " "] }) }, { children: tabs.map(tab => {
                console.log('tab', tab);
                return (_jsx(ListBoxItem, { label: tab.label || tab.language, textValue: tab.label || tab.language }, tab.key));
            }) })) })));
}
const CodeSelect = styled(CodeSelectUnstyled)(({ $isDisabled: _, theme: _t }) => ({
    display: 'flex',
    flexGrow: 1,
    justifyContent: 'right',
}));
function CodeContent(_a) {
    var { children, hasSetHeight } = _a, props = __rest(_a, ["children", "hasSetHeight"]);
    const [copied, setCopied] = useState(false);
    const codeString = (children === null || children === void 0 ? void 0 : children.trim()) || '';
    const multiLine = !!codeString.match(/\r?\n/) || hasSetHeight;
    const handleCopy = useCallback(() => window.navigator.clipboard
        .writeText(codeString)
        .then(() => setCopied(true)), [codeString]);
    useEffect(() => {
        if (copied) {
            const timeout = setTimeout(() => setCopied(false), 1000);
            return () => clearTimeout(timeout);
        }
    }, [copied]);
    if (typeof children !== 'string') {
        throw new Error('Code component expects a string as its children');
    }
    return (_jsxs(Div, Object.assign({ height: "100%", overflow: "auto", alignItems: "center" }, { children: [_jsx(CopyButton, { copied: copied, handleCopy: handleCopy, verticallyCenter: !multiLine }), _jsx(Div, Object.assign({ paddingHorizontal: "medium", paddingVertical: multiLine ? 'medium' : 'small' }, { children: _jsx(Highlight, Object.assign({}, props, { children: codeString })) }))] })));
}
function CodeRef(_a, ref) {
    var _b;
    var { children, language, showLineNumbers, showHeader, tabs, title, onSelectedTabChange } = _a, props = __rest(_a, ["children", "language", "showLineNumbers", "showHeader", "tabs", "title", "onSelectedTabChange"]);
    const parentFillLevel = useFillLevel();
    const tabStateRef = useRef();
    const [selectedTabKey, setSelectedTabKey] = useState((tabs && ((_b = tabs[0]) === null || _b === void 0 ? void 0 : _b.key)) || '');
    const theme = useTheme();
    const [tabInterface, setTabInterface] = useState();
    props.height = props.height || undefined;
    const hasSetHeight = !!props.height || !!props.minHeight;
    showHeader = tabs ? true : showHeader === undefined ? !!language : showHeader;
    const uiContext = useMemo(() => ({
        tabInterface,
        setTabInterface,
        tabs,
        tabStateRef,
        selectedKey: selectedTabKey,
        onSelectionChange: (key) => {
            setSelectedTabKey(key);
            if (typeof onSelectedTabChange === 'function') {
                onSelectedTabChange(key);
            }
        },
    }), [onSelectedTabChange, selectedTabKey, tabInterface, setTabInterface, tabs]);
    const titleArea = (tabs && title) || !tabs ? (_jsxs(TitleArea, Object.assign({ "$shrinkable": tabInterface === 'dropdown' || !tabs }, { children: [_jsx(FileIcon, {}), (title || language) && _jsx("div", { children: title || language })] }))) : undefined;
    const content = (_jsx(Card, Object.assign({ ref: ref, 
        // overflow="hidden"
        fillLevel: toFillLevel(Math.min(parentFillLevel + 1, 2)), borderColor: parentFillLevel >= 1
            ? theme.colors['border-fill-three']
            : theme.colors['border-fill-two'] }, props, { children: _jsxs(Flex, Object.assign({ position: "relative", direction: "column", height: "100%" }, { children: [showHeader && (_jsxs(_Fragment, { children: [_jsxs(CodeHeader, Object.assign({ fillLevel: parentFillLevel, "$visuallyHidden": tabInterface === 'dropdown' }, { children: [titleArea, tabs && _jsx(CodeTabs, {})] })), tabInterface === 'dropdown' && (_jsxs(CodeHeader, Object.assign({ fillLevel: parentFillLevel }, { children: [titleArea, _jsx(CodeSelect, {})] })))] })), tabs ? (tabs.map(tab => (_jsx(TabPanel, Object.assign({ tabKey: tab.key, mode: "multipanel", stateRef: tabStateRef, as: (_jsx(Div, { position: "relative", height: "100%", overflow: "hidden" })) }, { children: _jsx(CodeContent, Object.assign({ language: tab.language, showLineNumbers: showLineNumbers, hasSetHeight: hasSetHeight }, { children: tab.content })) }), tab.key)))) : (_jsx(Div, Object.assign({ position: "relative", height: "100%", overflow: "hidden" }, { children: _jsx(CodeContent, Object.assign({ language: language, showLineNumbers: showLineNumbers, hasSetHeight: hasSetHeight }, { children: children })) })))] })) })));
    return (_jsx(TabsContext.Provider, Object.assign({ value: uiContext }, { children: content })));
}
const Code = styled(forwardRef(CodeRef))(_ => ({
    [CopyButton]: {
        opacity: 0,
        pointerEvents: 'none',
        transition: 'opacity 0.2s ease',
    },
    [`&:hover ${CopyButton}`]: {
        opacity: 1,
        pointerEvents: 'auto',
        transition: 'opacity 0.2s ease',
    },
}));
Code.propTypes = propTypes;
export default Code;
//# sourceMappingURL=Code.js.map