var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useEffect, useMemo, useRef, useState, } from 'react';
import { useComboBox } from '@react-aria/combobox';
import { useComboBoxState } from '@react-stately/combobox';
import { useButton } from '@react-aria/button';
import pick from 'lodash/pick';
import omit from 'lodash/omit';
import isUndefined from 'lodash/isUndefined';
import styled, { useTheme } from 'styled-components';
import { ExtendTheme, mergeTheme } from 'honorable';
import { omitBy } from 'lodash';
import DropdownArrowIcon from './icons/DropdownArrowIcon';
import Input from './Input';
import { setNextFocusedKey, useSelectComboStateProps } from './SelectComboShared';
import { PopoverListBox } from './PopoverListBox';
import SearchIcon from './icons/SearchIcon';
import { SelectInner } from './Select';
export const ComboBoxInputInner = styled.div(({ theme, isOpen }) => ({
    '.arrow': Object.assign({ transition: 'transform 0.1s ease', display: 'flex', marginLeft: theme.spacing.medium, alignItems: 'center' }, (isOpen
        ? {
            transform: 'scaleY(-100%)',
        }
        : {})),
}));
const OpenButton = styled((_a) => {
    var { isOpen: _isOpen, buttonRef, buttonProps } = _a, props = __rest(_a, ["isOpen", "buttonRef", "buttonProps"]);
    const { buttonProps: useButtonProps } = useButton(Object.assign(Object.assign({}, buttonProps), { elementType: 'div' }), buttonRef);
    return (_jsx("div", Object.assign({ ref: buttonRef }, props, useButtonProps, { children: _jsx(DropdownArrowIcon, {}) })));
})(({ theme, isOpen }) => (Object.assign({ cursor: 'pointer', display: 'flex', alignItems: 'center', paddingLeft: theme.spacing.medium, paddingRight: theme.spacing.medium }, theme.partials.dropdown.arrowTransition({ isOpen }))));
const StartIconButton = styled.div(({ theme }) => ({
    cursor: 'pointer',
    display: 'flex',
    alignItems: 'center',
    paddingLeft: theme.spacing.medium,
    paddingRight: theme.spacing.medium,
}));
const comboBoxLeftRightStyles = {
    alignSelf: 'stretch',
    paddingHorizontal: 0,
    marginLeft: 0,
    marginRight: 0,
};
const honorableInputPropNames = [
    'onChange',
    'onFocus',
    'onBlur',
    'onKeyDown',
    'onKeyUp',
];
function ComboBoxInput({ startIcon, children: _children, inputRef, inputProps, outerInputProps, buttonRef, buttonProps, showArrow = true, isOpen, onInputClick, }) {
    outerInputProps = Object.assign(Object.assign({}, outerInputProps), pick(inputProps, honorableInputPropNames));
    const theme = useTheme();
    // Need to filter out undefined properties so they won't override
    // outerInputProps for honorable <Input> component
    const innerInputProps = useMemo(() => omitBy(omit(inputProps, honorableInputPropNames), isUndefined), [inputProps]);
    let themeExtension = {};
    if (startIcon) {
        themeExtension = mergeTheme(themeExtension, {
            Input: {
                Root: [
                    {
                        position: 'relative',
                        paddingLeft: 0,
                    },
                ],
                InputBase: [{ paddingLeft: theme.spacing.xxlarge }],
                StartIcon: [
                    {
                        position: 'absolute',
                        top: 0,
                        left: 0,
                        bottom: 0,
                        pointerEvents: 'none',
                    },
                ],
            },
        });
    }
    if (showArrow) {
        themeExtension = mergeTheme(themeExtension, {
            Input: {
                Root: [{ paddingRight: 0 }],
                EndIcon: [
                    Object.assign({}, comboBoxLeftRightStyles),
                ],
            },
        });
    }
    return (_jsx(ExtendTheme, Object.assign({ theme: themeExtension }, { children: _jsx(Input, Object.assign({ startIcon: startIcon && _jsx(StartIconButton, { children: startIcon }), endIcon: showArrow ? (_jsx(OpenButton, { isOpen: isOpen, buttonRef: buttonRef, buttonProps: buttonProps })) : undefined, inputProps: Object.assign({ ref: inputRef, onClick: onInputClick }, innerInputProps) }, outerInputProps)) })));
}
const ComboBoxInner = styled(SelectInner)(_p => ({}));
function ComboBox(_a) {
    var { children, selectedKey, inputValue, onSelectionChange, onFocusChange, onOpenChange, onInputChange, isOpen, dropdownHeader, dropdownFooter, dropdownHeaderFixed, dropdownFooterFixed, onHeaderClick, onFooterClick, showArrow, startIcon, placement, width, maxHeight, inputProps: outerInputProps } = _a, props = __rest(_a, ["children", "selectedKey", "inputValue", "onSelectionChange", "onFocusChange", "onOpenChange", "onInputChange", "isOpen", "dropdownHeader", "dropdownFooter", "dropdownHeaderFixed", "dropdownFooterFixed", "onHeaderClick", "onFooterClick", "showArrow", "startIcon", "placement", "width", "maxHeight", "inputProps"]);
    const nextFocusedKeyRef = useRef(null);
    const stateRef = useRef(null);
    const [isOpenUncontrolled, setIsOpenUncontrolled] = useState(false);
    const previousInputValue = useRef(inputValue);
    if (typeof isOpen !== 'boolean') {
        isOpen = isOpenUncontrolled;
    }
    const wrappedOnOpenChange = useCallback((nextIsOpen, menuTrigger) => {
        setIsOpenUncontrolled(nextIsOpen);
        if (nextIsOpen !== isOpen) {
            if (onOpenChange)
                onOpenChange(nextIsOpen, menuTrigger);
        }
    }, [isOpen, onOpenChange]);
    const setIsOpen = useCallback((isOpen) => {
        wrappedOnOpenChange(isOpen, 'manual');
    }, [wrappedOnOpenChange]);
    const wrappedOnSelectionChange = useCallback((newKey, ...args) => {
        if (onSelectionChange) {
            onSelectionChange.apply(this, [
                typeof newKey === 'string' ? newKey : '',
                ...args,
            ]);
            setIsOpen(false);
        }
    }, [onSelectionChange, setIsOpen]);
    const wrappedOnFocusChange = useCallback((isFocused, ...args) => {
        // Enforce open on focus
        if (isFocused && !isOpen) {
            setIsOpen(true);
        }
        if (onFocusChange) {
            onFocusChange(isFocused, ...args);
        }
    }, [isOpen, onFocusChange, setIsOpen]);
    const wrappedOnInputChange = useCallback((input, ...args) => {
        if (input !== previousInputValue.current) {
            previousInputValue.current = input;
            setIsOpen(true);
        }
        if (onInputChange) {
            onInputChange(input, ...args);
        }
    }, [onInputChange, setIsOpen]);
    const comboStateBaseProps = useSelectComboStateProps({
        dropdownHeader,
        dropdownFooter,
        onFooterClick,
        onHeaderClick,
        onOpenChange: wrappedOnOpenChange,
        onSelectionChange: wrappedOnSelectionChange,
        children,
        setIsOpen,
        stateRef,
        nextFocusedKeyRef,
    });
    const comboStateProps = Object.assign(Object.assign(Object.assign({}, comboStateBaseProps), { menuTrigger: 'manual', selectedKey: selectedKey || null, onFocusChange: wrappedOnFocusChange, onInputChange: wrappedOnInputChange, inputValue }), props);
    const state = useComboBoxState(Object.assign({}, comboStateProps));
    setNextFocusedKey({ nextFocusedKeyRef, state, stateRef });
    useEffect(() => {
        if (isOpen !== state.isOpen) {
            if (isOpen) {
                state.open(null, 'manual');
            }
            else {
                state.close();
            }
        }
    }, [state, isOpen]);
    const buttonRef = useRef(null);
    const inputRef = useRef(null);
    const listBoxRef = useRef(null);
    const popoverRef = useRef(null);
    const { buttonProps, inputProps, listBoxProps } = useComboBox(Object.assign(Object.assign({}, comboStateProps), { inputRef,
        buttonRef,
        listBoxRef,
        popoverRef }), state);
    if (startIcon === undefined) {
        startIcon = _jsx(SearchIcon, {});
    }
    return (_jsxs(ComboBoxInner, Object.assign({ "$isOpen": state.isOpen, "$maxHeight": maxHeight, "$placement": placement }, { children: [_jsx(ComboBoxInput, { inputRef: inputRef, inputProps: inputProps, buttonRef: buttonRef, buttonProps: buttonProps, showArrow: showArrow, isOpen: state.isOpen, setIsOpen: setIsOpen, startIcon: startIcon, outerInputProps: outerInputProps, onInputClick: () => {
                    setIsOpen(true);
                    // Need to also manually open with state to override
                    // default close behavior
                    state.open(null, 'manual');
                } }), _jsx(PopoverListBox, { isOpen: state.isOpen, onClose: state.close, listBoxState: state, listBoxProps: listBoxProps, popoverRef: popoverRef, listBoxRef: listBoxRef, dropdownHeaderFixed: dropdownHeaderFixed, dropdownFooterFixed: dropdownFooterFixed, width: width, placement: placement })] })));
}
export { ComboBox };
//# sourceMappingURL=ComboBox.js.map