var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Children, cloneElement, useMemo, useRef, } from 'react';
import { useListBox, useOption } from '@react-aria/listbox';
import { useListState } from '@react-stately/list';
import { mergeProps } from '@react-aria/utils';
import { mergeRefs } from 'react-merge-refs';
import styled, { useTheme } from 'styled-components';
import { Item } from '@react-stately/collections';
import Card from './Card';
export const HEADER_KEY = '$$header$$';
export const FOOTER_KEY = '$$footer$$';
const CARD_FILL_LEVEL = 2;
const ListBoxCard = styled(Card).attrs(() => ({
    cornerSize: 'medium',
    fillLevel: CARD_FILL_LEVEL,
}))(_p => ({
    display: 'flex',
    flexDirection: 'column',
    flexShrink: 1,
    overflowX: 'visible',
    overflowY: 'hidden',
}));
const ScrollContainer = styled.div(({ theme, extendStyle }) => (Object.assign(Object.assign(Object.assign({}, theme.partials.scrollBar({ fillLevel: CARD_FILL_LEVEL })), { position: 'relative', overflow: 'auto', flexShrink: 1, flexGrow: 1, '&:focus': {
        outline: 'none',
    }, '&:focus-visible::after': Object.assign({}, theme.partials.focus.insetAbsolute) }), extendStyle)));
function useItemWrappedChildren(children, header, footer) {
    return useMemo(() => {
        // Children.map() prefixes the key props in an undocumented and possibly
        // unstable way, so using Children.forEach() to maintain original key values
        const wrapped = [];
        if (header) {
            wrapped.push(_jsx(Item, { children: header }, HEADER_KEY));
        }
        Children.forEach(children, child => {
            const _a = (child === null || child === void 0 ? void 0 : child.props) || {}, { textValue } = _a, childProps = __rest(_a, ["textValue"]);
            if (child) {
                const item = (_jsx(Item, Object.assign({ textValue: textValue || '' }, { children: cloneElement(child, childProps) }), child.key));
                wrapped.push(item);
            }
        });
        if (footer) {
            wrapped.push(_jsx(Item, { children: footer }, FOOTER_KEY));
        }
        return wrapped;
    }, [children, header, footer]);
}
function ListBox(_a) {
    var { disallowEmptySelection, selectedKey, children, header, footer, onSelectionChange, onHeaderClick, onFooterClick } = _a, props = __rest(_a, ["disallowEmptySelection", "selectedKey", "children", "header", "footer", "onSelectionChange", "onHeaderClick", "onFooterClick"]);
    const nextFocusedKeyRef = useRef(null);
    const stateRef = useRef(null);
    const selected = useMemo(() => new Set(selectedKey ? [selectedKey] : null), [selectedKey]);
    const listStateProps = {
        disallowEmptySelection,
        selectionMode: 'single',
        selectedKeys: selected,
        onSelectionChange: selection => {
            var _a, _b;
            const [newKey] = selection;
            if (newKey === HEADER_KEY && onHeaderClick) {
                onHeaderClick();
            }
            else if (newKey === FOOTER_KEY && onFooterClick) {
                onFooterClick();
                if (stateRef.current) {
                    nextFocusedKeyRef.current
                        = (_b = (_a = stateRef === null || stateRef === void 0 ? void 0 : stateRef.current) === null || _a === void 0 ? void 0 : _a.collection) === null || _b === void 0 ? void 0 : _b.getKeyBefore(FOOTER_KEY);
                }
            }
            else if (onSelectionChange) {
                onSelectionChange(newKey);
            }
        },
        children: useItemWrappedChildren(children, header, footer),
    };
    const state = useListState(listStateProps);
    stateRef.current = state;
    if (nextFocusedKeyRef.current) {
        const focusedKey = state.collection.getKeyAfter(nextFocusedKeyRef.current)
            || nextFocusedKeyRef.current;
        state.selectionManager.setFocusedKey(focusedKey);
        nextFocusedKeyRef.current = null;
    }
    return (_jsx(ListBoxUnmanaged, Object.assign({ state: state }, props)));
}
function ListBoxUnmanaged(_a) {
    var { state, headerFixed, footerFixed, extendStyle, className, listBoxRef } = _a, props = __rest(_a, ["state", "headerFixed", "footerFixed", "extendStyle", "className", "listBoxRef"]);
    const theme = useTheme();
    // Get props for the listbox element
    let ref = useRef();
    if (listBoxRef) {
        ref = listBoxRef;
    }
    const { listBoxProps } = useListBox(props, state, ref);
    return (_jsxs(ListBoxCard, Object.assign({ className: `listBox ${className || ''}` }, extendStyle, props, { children: [headerFixed && _jsx("div", Object.assign({ className: "headerFixed" }, { children: headerFixed })), _jsx(ScrollContainer, Object.assign({ ref: ref, extendStyle: {
                    paddingTop: headerFixed ? 0 : theme.spacing.xxxsmall,
                    paddingBottom: footerFixed ? 0 : theme.spacing.xxxsmall,
                } }, listBoxProps, { children: [...state.collection].map(item => (_jsx(Option, { item: item, state: state }, item.key))) })), footerFixed && _jsx("div", Object.assign({ className: "footerFixed" }, { children: footerFixed }))] })));
}
function Option({ item, state }) {
    var _a, _b, _c, _d;
    // Get props for the option element
    const ref = useRef();
    const { optionProps, isSelected, isDisabled, labelProps, descriptionProps, isFocused, } = useOption({ key: item.key }, state, ref);
    const mergedProps = mergeProps(optionProps, {
        selected: isSelected || ((_b = (_a = item === null || item === void 0 ? void 0 : item.rendered) === null || _a === void 0 ? void 0 : _a.props) === null || _b === void 0 ? void 0 : _b.selected),
        disabled: isDisabled || ((_d = (_c = item === null || item === void 0 ? void 0 : item.rendered) === null || _c === void 0 ? void 0 : _c.props) === null || _d === void 0 ? void 0 : _d.disabled),
        focused: isFocused,
        labelProps,
        descriptionProps,
        ref: mergeRefs([ref, item.rendered.ref]),
    });
    return cloneElement(item.rendered, mergedProps);
}
export { ListBox, ListBoxUnmanaged, useItemWrappedChildren, };
//# sourceMappingURL=ListBox.js.map