var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Div, Flex, H1, Img, Span, } from 'honorable';
import { keyframes } from '@emotion/react';
import styled from 'styled-components';
import { forwardRef, useCallback, useEffect, useLayoutEffect, useMemo, useRef, useState, } from 'react';
import { CSSTransition } from 'react-transition-group';
import useResizeObserver from '../hooks/useResizeObserver';
const bgKeyframes = keyframes `
  0% {
    transform: translateX(0);
  }
  100% {
    transform: translate(calc(-200% / 3));
  }
`;
const commonAnimStyles = {
    animationDuration: '3s',
    animationTimingFunction: 'linear',
    animationIterationCount: 'infinite',
};
const logoEnterStyles = {
    '.enter &': {
        opacity: 0,
        transform: 'scale(0.3)',
    },
    '.enter-active &, .enter-done &': {
        opacity: 1,
        transform: 'scale(1)',
        visibility: 'visible',
    },
    '.enter-active &': {
        transition: 'all 0.3s cubic-bezier(.37,1.4,.62,1)',
    },
};
const textEnterStyles = {
    '.enter &': {
        opacity: 0,
    },
    '.enter-active &, .enter-done &': {
        opacity: 1,
    },
    '.enter-active &': {
        transition: 'all 0.3s ease',
    },
};
const exitStyles = {
    '&.exit': {
        opacity: 1,
    },
    '&.exit-active, &.exit-done': {
        opacity: 0,
    },
    '&.exit-active': {
        transition: 'all 0.1s ease-in',
    },
};
/*
    A bunch of nasty calcs to get the spinner optically centered across
    different viewport heights. Once the vh goes beyond --clampMin, the
    spinner gets shifted up proportional to vh until it reaches --clampMax.
    Units are kinda weird because calc() won't allow a value with units
    as a denominator.
*/
const CenteringWrapperBase = styled(WrapperBase) `
  --clampMin: 250;
  --clampMax: 1000;
  --initialShift: 7px;
  --shiftMultiplier: -13;
  --shiftRatio: calc(
    (${({ areaHeight }) => areaHeight} - (var(--clampMin) * 1px)) /
      (var(--clampMax) - var(--clampMin))
  );
  --clampedShiftRatio: calc(max(0px, min(1px, var(--shiftRatio))));
  --translateAmt: calc(
    (var(--initialShift) + (var(--shiftMultiplier) * var(--clampedShiftRatio)))
  );
  transform: translateY(var(--translateAmt));
`;
function ScrollingBGImageBase(_a) {
    var { height } = _a, props = __rest(_a, ["height"]);
    const styles = {
        background: 'url(/page-load-spinner/page-load-spinner-bg.png)',
        backgroundSize: '100% auto',
        backgroundRepeat: 'repeat-y',
        height,
        width: height * 6,
        ':nth-child(2n)': {
            transform: 'rotate(180deg)',
        },
    };
    return (_jsx(Div, Object.assign({}, styles, props)));
}
const ScrollingBGImage = styled(ScrollingBGImageBase) `
  @supports (aspect-ratio: 6 / 1) {
    height: 100%;
    width: auto;
    aspect-ratio: 6 / 1;
  }
`;
function WrapperBase(props) {
    return (_jsx(Flex, Object.assign({ direction: "column", alignItems: "center", justifyContent: "center", overflow: "hidden", width: "auto" }, props)));
}
function CenteringWrapper(_a) {
    var { children } = _a, props = __rest(_a, ["children"]);
    const [top, setTop] = useState(null);
    const [windowHeight, setWindowHeight] = useState(window.innerHeight);
    const ref = useRef();
    const onSizeChange = useCallback(() => {
        const nextTop = ref.current.getBoundingClientRect().top;
        if (nextTop !== top) {
            setTop(nextTop);
        }
        if (window.innerHeight !== windowHeight) {
            setWindowHeight(window.innerHeight - nextTop);
        }
    }, [top, windowHeight]);
    useResizeObserver(ref, onSizeChange);
    useLayoutEffect(() => {
        window.addEventListener('resize', onSizeChange);
        window.addEventListener('scroll', onSizeChange);
        return () => {
            window.removeEventListener('resize', onSizeChange);
            window.removeEventListener('scroll', onSizeChange);
        };
    });
    const wrapperHeight = useMemo(() => `${top === null || windowHeight === null ? '100vh' : windowHeight - top}px`, [top, windowHeight]);
    return (_jsx(Flex, Object.assign({ position: "absolute", className: "centering", ref: ref, direction: "column", alignItems: "center", justifyContent: "center", overflow: "hidden", paddingHorizontal: "small", width: "100%", height: wrapperHeight }, props, { children: _jsx(CenteringWrapperBase, Object.assign({ areaHeight: wrapperHeight }, { children: children })) })));
}
const Wrapper = forwardRef((_a, ref) => {
    var { centered, children } = _a, props = __rest(_a, ["centered", "children"]);
    return (_jsx(Div, Object.assign({ ref: ref }, exitStyles, props, { children: centered ? (_jsx(CenteringWrapper, { children: children })) : (_jsx(WrapperBase, { children: children })) })));
});
const LoadingSpinner = forwardRef((_a, ref) => {
    var { show = true, paused, spinnerWidth = 96, spinnerDelay = 200, centered = false, animateTransitions = true } = _a, props = __rest(_a, ["show", "paused", "spinnerWidth", "spinnerDelay", "centered", "animateTransitions"]);
    const [delayFinished, setDelayFinished] = useState(false);
    const [tickCount, setTickCount] = useState(0);
    if (!show && delayFinished) {
        setDelayFinished(false);
    }
    useEffect(() => {
        if (show) {
            const timeoutId = setTimeout(() => {
                setDelayFinished(true);
            }, spinnerDelay);
            return () => {
                clearTimeout(timeoutId);
            };
        }
    }, [show, spinnerDelay]);
    useEffect(() => {
        const interval = setTimeout(() => {
            setTickCount(tickCount >= 4 ? 0 : tickCount + 1);
        }, 200);
        return () => clearTimeout(interval);
    }, [tickCount]);
    return (_jsx(CSSTransition, Object.assign({ in: delayFinished && show, appear: true, timeout: animateTransitions ? 400 : 0, unmountOnExit: true }, { children: _jsxs(Wrapper, Object.assign({ ref: ref, centered: centered, className: "wrapper" }, props, { children: [_jsxs(Div, Object.assign({ mask: "url(/logos/plural-logomark-only-white.svg) 0 0 / contain no-repeat", background: "url(/logos/plural-logomark-only-white.svg)", backgroundSize: "contain", overflow: "hidden", width: spinnerWidth, height: "auto", position: "relative" }, logoEnterStyles, { children: [_jsx(Img, { display: "block", width: "100%", visibility: "hidden", src: "/logos/plural-logomark-only-white.svg" }), _jsxs(Flex, Object.assign({ flexWrap: "nowrap", height: "100%", position: "absolute", top: "0", animationName: bgKeyframes, animationPlayState: paused ? 'paused' : 'running' }, commonAnimStyles, { children: [_jsx(ScrollingBGImage, { height: spinnerWidth }), _jsx(ScrollingBGImage, { height: spinnerWidth }), _jsx(ScrollingBGImage, { height: spinnerWidth })] }))] })), _jsxs(H1, Object.assign({ body1: true, bold: true, color: "text", marginTop: "large", textAlign: "center" }, textEnterStyles, { children: ["Loading Plural", _jsx(Span, Object.assign({ opacity: tickCount >= 1 ? 1 : 0 }, { children: "." })), _jsx(Span, Object.assign({ opacity: tickCount >= 2 ? 1 : 0 }, { children: "." })), _jsx(Span, Object.assign({ opacity: tickCount >= 3 ? 1 : 0 }, { children: "." }))] }))] })) })));
});
export default LoadingSpinner;
//# sourceMappingURL=LoadingSpinner.js.map