import { useRef, } from 'react';
import { FOOTER_KEY, HEADER_KEY, useItemWrappedChildren } from './ListBox';
function useSelectComboStateProps({ setIsOpen, onOpenChange, onFooterClick, onHeaderClick, onSelectionChange, dropdownHeader, dropdownFooter, stateRef, children, nextFocusedKeyRef, }) {
    const temporarilyPreventClose = useRef(false);
    return {
        onOpenChange: (open, ...args) => {
            if (!open && temporarilyPreventClose.current) {
                temporarilyPreventClose.current = false;
                return;
            }
            setIsOpen(open);
            if (onOpenChange) {
                onOpenChange.apply(this, [open, ...args]);
            }
        },
        onSelectionChange: (newKey, ...args) => {
            var _a, _b;
            if (newKey === HEADER_KEY && onHeaderClick) {
                temporarilyPreventClose.current = true;
                onHeaderClick();
            }
            else if (newKey === FOOTER_KEY && onFooterClick) {
                temporarilyPreventClose.current = true;
                onFooterClick();
                if (stateRef.current) {
                    nextFocusedKeyRef.current
                        = (_b = (_a = stateRef === null || stateRef === void 0 ? void 0 : stateRef.current) === null || _a === void 0 ? void 0 : _a.collection) === null || _b === void 0 ? void 0 : _b.getKeyBefore(FOOTER_KEY);
                }
            }
            else if (onSelectionChange) {
                onSelectionChange.apply(this, [
                    typeof newKey === 'string' ? newKey : '',
                    ...args,
                ]);
            }
        },
        children: useItemWrappedChildren(children, dropdownHeader, dropdownFooter),
    };
}
const setNextFocusedKey = ({ nextFocusedKeyRef, state, stateRef, }) => {
    stateRef.current = state;
    if (nextFocusedKeyRef.current) {
        const nextFocusedKey = nextFocusedKeyRef.current;
        const focusedKey = state.collection.getKeyAfter(nextFocusedKey) || nextFocusedKey;
        state.selectionManager.setFocusedKey(focusedKey);
        nextFocusedKeyRef.current = null;
    }
};
export { useSelectComboStateProps, setNextFocusedKey, useItemWrappedChildren };
//# sourceMappingURL=SelectComboShared.js.map