var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
// Tooltip Library docs: https://floating-ui.com/docs/react-dom
import { cloneElement, useMemo, useRef, useState, } from 'react';
import { FloatingPortal, arrow, autoUpdate, flip, offset, shift, useClick, useDismiss, useFloating, useFocus, useHover, useInteractions, useRole, } from '@floating-ui/react-dom-interactions';
import { mergeRefs } from 'react-merge-refs';
import { Div } from 'honorable';
import { CSSTransition } from 'react-transition-group';
import styled, { useTheme } from 'styled-components';
import createIcon from './icons/createIcon';
import WrapWithIf from './WrapWithIf';
const Tip = styled(Div) `
  &.enter {
    opacity: 0;
    transform: scale(0.5);
  }
  &.enter-active,
  &.enter-done {
    opacity: 1;
    transform: scale(1);
    visibility: visible;
  }
  &.enter-active {
    transition: transform 0.15s cubic-bezier(0.37, 1.4, 0.62, 1),
      opacity 0.1s linear;
  }
  &.exit {
    opacity: 1;
    transform: scale(1);
  }
  &.exit-active,
  &.exit-done {
    opacity: 0;
    transform: scale(0.3);
  }
  &.exit-active {
    transition: transform 0.05s ease-in, opacity 0.05s linear;
  }
`;
const TooltipArrow = createIcon(({ size, color }) => (_jsx("svg", Object.assign({ width: size, viewBox: "0 0 7 5", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, { children: _jsx("g", Object.assign({ fill: color }, { children: _jsx("path", { d: "m3.89468 3.99256c-.20018.25737-.58918.25737-.78936 0l-3.10531961-3.99256h6.99999961z" }) })) }))));
const ARROW_LENGTH = 5;
const ARROW_WIDTH = 7;
const DEFAULT_OFFSET = 4;
function Tooltip(_a) {
    var _b, _c;
    var { children, label, placement = 'right', displayOn = 'hover', manualOpen = null, arrowProps = {}, strategy = 'fixed', arrow: showArrow = true, dismissable = true, offset: tipOffset, portal = true, portalProps = {}, onOpenChange } = _a, props = __rest(_a, ["children", "label", "placement", "displayOn", "manualOpen", "arrowProps", "strategy", "arrow", "dismissable", "offset", "portal", "portalProps", "onOpenChange"]);
    const theme = useTheme();
    const [open, setOpen] = useState(false);
    const arrowRef = useRef();
    const isOpen = displayOn === 'none' ? false : displayOn === 'manual' ? manualOpen : open;
    const totalOffset = (showArrow ? ARROW_LENGTH : 0)
        + (typeof tipOffset === 'number' ? tipOffset : DEFAULT_OFFSET);
    const { x, y, reference, floating, strategy: finalStrategy, context, placement: finalPlacement, middlewareData, } = useFloating({
        placement,
        open: isOpen,
        strategy,
        onOpenChange: open => {
            setOpen(open);
            if (onOpenChange)
                onOpenChange(open);
        },
        middleware: [
            offset(totalOffset),
            flip(),
            shift({ padding: 12 }),
            ...(showArrow ? [arrow({ element: arrowRef })] : []),
        ],
        whileElementsMounted: autoUpdate,
    });
    const { getReferenceProps, getFloatingProps } = useInteractions([
        useHover(context, {
            enabled: displayOn === 'hover',
            restMs: 25,
            delay: { open: 0, close: 0 },
        }),
        useClick(context, { enabled: displayOn === 'click' }),
        useFocus(context, { enabled: displayOn === 'focus' }),
        useRole(context, { role: 'tooltip' }),
        useDismiss(context, { enabled: dismissable === true }),
    ]);
    // Preserve the consumer's ref
    const childrenRef = useMemo(() => mergeRefs([reference, children.ref]), [reference, children]);
    const finalPlacementSide = `${finalPlacement}`.split('-')[0];
    const arrowRotation = {
        top: 0,
        right: 90,
        bottom: 180,
        left: -90,
    }[finalPlacementSide];
    const staticSide = {
        top: 'bottom',
        right: 'left',
        bottom: 'top',
        left: 'right',
    }[finalPlacementSide];
    const transformOrigin = {
        top: 'top center',
        right: 'center right',
        bottom: 'bottom center',
        left: 'center left',
    }[staticSide];
    return (_jsxs(_Fragment, { children: [cloneElement(children, getReferenceProps(Object.assign({ ref: childrenRef }, children.props))), _jsx(WrapWithIf, Object.assign({ condition: portal, wrapper: (_jsx(FloatingPortal, Object.assign({ id: theme.portals.default.id }, portalProps))) }, { children: _jsx(CSSTransition, Object.assign({ in: isOpen, appear: true, timeout: 250, mountOnEnter: true, unmountOnExit: true }, { children: _jsxs(Tip, Object.assign({ ref: floating, caption: true, color: "text-light", borderRadius: "medium", paddingVertical: "xsmall", paddingHorizontal: "small", backgroundColor: "fill-two", boxShadow: theme.boxShadows.moderate, userSelect: "none", style: {
                            position: finalStrategy,
                            left: x !== null && x !== void 0 ? x : 0,
                            top: y !== null && y !== void 0 ? y : 0,
                        }, transformOrigin: transformOrigin, zIndex: theme.zIndexes.tooltip, pointerEvents: "none" }, props, getFloatingProps(), { children: [label, showArrow && (_jsx(Div, Object.assign({ ref: arrowRef, style: {
                                    position: 'absolute',
                                    top: ((_b = middlewareData === null || middlewareData === void 0 ? void 0 : middlewareData.arrow) === null || _b === void 0 ? void 0 : _b.y) || '',
                                    left: ((_c = middlewareData === null || middlewareData === void 0 ? void 0 : middlewareData.arrow) === null || _c === void 0 ? void 0 : _c.x) || '',
                                    [staticSide]: `-${ARROW_WIDTH}px`,
                                }, width: ARROW_WIDTH, height: ARROW_WIDTH, transform: `rotate(${arrowRotation}deg)` }, arrowProps, { children: _jsx(TooltipArrow, { position: "absolute", top: 0, left: 0, size: ARROW_WIDTH, color: "fill-two" }) })))] })) })) }))] }));
}
export default Tooltip;
//# sourceMappingURL=Tooltip.js.map