import { useCallback, useLayoutEffect } from 'react';
import ResizeObserver from 'resize-observer-polyfill';
const useResizeObserver = (ref, callback) => {
    const handleResize = useCallback((entries) => {
        if (!Array.isArray(entries)) {
            return;
        }
        const entry = entries[0];
        if (callback) {
            callback(entry.contentRect);
        }
    }, [callback]);
    useLayoutEffect(() => {
        if (!ref.current) {
            return;
        }
        let RO = new ResizeObserver((entries) => handleResize(entries));
        RO.observe(ref.current);
        return () => {
            RO.disconnect();
            RO = null;
        };
    }, [ref, handleResize]);
};
export default useResizeObserver;
//# sourceMappingURL=useResizeObserver.js.map