import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Div, Flex } from 'honorable';
import { forwardRef, useState, } from 'react';
import styled from 'styled-components';
import { AppIcon, Button, CheckIcon, Chip, DropdownArrowIcon, InfoIcon, ListBoxFooterPlus, ListBoxItem, ListBoxItemChipList, PersonIcon, SearchIcon, Select, SelectButton, } from '../index';
export default {
    title: 'Select',
    component: 'Select',
};
const portrait = (_jsx(AppIcon, { spacing: "none", size: "xsmall", url: "photo.png" }));
const smallIcon = _jsx(PersonIcon, { size: 16 });
const chipProps = {
    size: 'small',
    hue: 'lighter',
};
const chips = [
    _jsx(Chip, Object.assign({ severity: "success" }, chipProps, { children: "Installed" })),
    _jsx(Chip, Object.assign({ severity: "neutral" }, chipProps, { children: "Warm" })),
    _jsx(Chip, Object.assign({ severity: "neutral" }, chipProps, { children: "Latest" })),
    _jsx(Chip, Object.assign({ severity: "warning" }, chipProps, { children: "Additional" })),
    _jsx(Chip, Object.assign({ severity: "error" }, chipProps, { children: "Extra" })),
    _jsx(Chip, Object.assign({ severity: "info" }, chipProps, { children: "Another" })),
];
const items = [
    {
        key: 'ratatouille',
        label: 'Ratatouille',
        description: 'With ham and cheese',
        chips: chips.slice(0, 1),
        version: '0.2.24',
    },
    {
        key: 'pizza',
        label: 'Pizza',
        description: 'With ham and cheese',
        chips: chips.slice(1, 3),
        version: '0.2.25',
    },
    {
        key: 'sushi',
        label: 'Sushi',
        description: 'With ham and cheese',
        chips: null,
        version: '0.2.26',
    },
    {
        key: 'couscous',
        label: 'Couscous',
        description: 'With ham and cheese',
        chips: chips.slice(4),
        version: '0.3.00',
    },
    {
        key: 'dim-sum',
        label: 'Dim Sum',
        description: 'With ham and cheese',
        chips: chips.slice(4, 5),
        version: '0.3.01',
    },
    {
        key: 'ratatouille2',
        label: 'Ratatouille',
        description: 'With ham and cheese',
        chips: [chips[0], chips[3], chips[5]],
        version: '0.3.02',
    },
    {
        key: 'pizza2',
        label: 'Pizza',
        description: 'With ham and cheese',
        chips: [chips[5], chips[0]],
        version: '0.3.05',
    },
    {
        key: 'sushi2',
        label: 'Sushi',
        description: 'With ham and cheese',
        chips: chips.slice(0),
        version: '0.3.12',
    },
    {
        key: 'couscous2',
        label: 'Couscous',
        description: 'With ham and cheese',
        chips: chips.slice(0).reverse(),
        version: '0.4.00',
    },
    {
        key: 'dim-sum2',
        label: 'Dim Sum',
        description: 'With ham and cheese',
        chips: chips.slice(5).reverse(),
        version: '0.4.01',
    },
];
// Make sure any custom trigger button forwards ref to outermost element,
// otherwise it'll error
const CustomTriggerButton = styled(forwardRef((props, ref) => (_jsx(Button, Object.assign({ ref: ref, medium: true, primary: true, endIcon: _jsx(DropdownArrowIcon, { className: "dropdownIcon" }) }, props, { children: "Click me!" })))))(({ isOpen = false }) => ({
    '.dropdownIcon': {
        transform: isOpen ? 'scaleY(-1)' : 'scaleY(1)',
        transition: 'transform 0.1s ease',
    },
}));
function Template() {
    const [selectedKey, setSelectedKey] = useState();
    const shownStep = 4;
    const [shownLimit, setShownLimit] = useState(shownStep);
    const curItem = items.find(item => item.key === selectedKey);
    const customLabel = curItem
        ? `You have selected ${curItem.label}`
        : 'Select an item please';
    return (_jsxs(Flex, Object.assign({ flexDirection: "column", gap: "large", maxWidth: 512 }, { children: [_jsx(Div, { children: _jsx(Select, Object.assign({ defaultOpen: false, label: "Pick something", selectedKey: selectedKey, onSelectionChange: key => {
                        setSelectedKey(key);
                    } }, { children: items.slice(0, 4).map(({ key, label }) => (_jsx(ListBoxItem, { label: label, textValue: label, leftContent: smallIcon }, key))) })) }), _jsx(Div, { children: _jsx(Select, Object.assign({ label: "Pick something", selectedKey: selectedKey, onSelectionChange: key => {
                        setSelectedKey(key);
                    }, defaultOpen: false, leftContent: _jsx(SearchIcon, {}), rightContent: _jsx(ListBoxItemChipList, { chips: curItem === null || curItem === void 0 ? void 0 : curItem.chips }), dropdownFooterFixed: _jsx(ListBoxFooterPlus, { children: "Create new" }) }, { children: items.map(({ key, label, description, chips, }) => (_jsx(ListBoxItem, { label: label, textValue: label, description: description, rightContent: _jsx(ListBoxItemChipList, { chips: chips }), leftContent: portrait }, key))) })) }), _jsx(Div, { children: _jsx(Select, Object.assign({ label: "Pick something", selectedKey: selectedKey, onSelectionChange: key => {
                        setSelectedKey(key);
                    }, defaultOpen: false, dropdownFooterFixed: _jsx(ListBoxFooterPlus, { children: "Create new" }), triggerButton: (_jsx(SelectButton, Object.assign({ leftContent: curItem ? _jsx(CheckIcon, {}) : _jsx(InfoIcon, {}) }, { children: customLabel }))) }, { children: items.map(({ key, label, description, chips, }) => (_jsx(ListBoxItem, { label: label, textValue: label, description: description, rightContent: _jsx(ListBoxItemChipList, { chips: chips }), leftContent: portrait }, key))) })) }), _jsx(Flex, Object.assign({ justifyContent: "right" }, { children: _jsx(Select, Object.assign({ label: "Version", selectedKey: selectedKey, triggerButton: _jsx(CustomTriggerButton, {}), width: "max-content", maxHeight: 197, placement: "right", onSelectionChange: key => {
                        setSelectedKey(key);
                    }, onFooterClick: () => setShownLimit(shownLimit + shownStep), onOpenChange: open => {
                        if (!open)
                            setShownLimit(shownStep);
                    }, rightContent: curItem && (_jsx(ListBoxItemChipList, { maxVisible: 0, showExtra: true, chips: curItem.chips })), dropdownFooter: shownLimit < items.length && (_jsx(ListBoxFooterPlus, { children: "View more" })) }, { children: items.slice(0, shownLimit).map(({ key, chips, version }) => (_jsx(ListBoxItem, { label: version, textValue: version, rightContent: (_jsx(ListBoxItemChipList, { maxVisible: 1, showExtra: true, chips: chips })) }, key))) })) }))] })));
}
export const Default = Template.bind({});
Default.args = {};
//# sourceMappingURL=Select.stories.js.map