import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import styled, { useTheme } from 'styled-components';
import Divider from '../components/Divider';
const fillLevelToBGColor = {
    0: 'fill-zero',
    1: 'fill-one',
    2: 'fill-two',
    3: 'fill-three',
};
export default {
    title: 'Semantic System',
    component: null,
};
const ItemLabel = styled.div(({ theme }) => (Object.assign(Object.assign({}, theme.partials.text.caption), { marginTop: theme.spacing.xxsmall })));
const BlockWrapper = styled.div(({ theme }) => ({
    marginBottom: theme.spacing.large,
}));
const FilledBox = styled.div(({ theme }) => ({
    width: '64px',
    height: '64px',
    backgroundColor: theme.colors['fill-one'],
}));
function Template({ exampleText }) {
    return (_jsxs(_Fragment, { children: [_jsx(Divider, { text: "Colors", marginVertical: "xxlarge" }), _jsx(Colors, {}), _jsx(Divider, { text: "Shadows", marginVertical: "xxlarge" }), _jsx(Shadows, {}), _jsx(Divider, { text: "Borders", marginVertical: "xxlarge" }), _jsx(BoxBorders, {}), _jsx(Divider, { text: "Scrollbars", marginVertical: "xxlarge" }), _jsx(Scrollbars, {}), _jsx(Divider, { text: "Border radiuses", marginVertical: "xxlarge" }), _jsx(BoxRadiuses, {}), _jsx(Divider, { text: "Spacing", marginVertical: "xxlarge" }), _jsx(Spacing, {}), _jsx(Divider, { text: "Typography", marginVertical: "xxlarge" }), _jsx(Typography, { exampleText: exampleText }), _jsx(Divider, { text: "Marketing Typography", marginVertical: "xxlarge" }), _jsx(MarketingTypography, { exampleText: exampleText })] }));
}
const ColorBox = styled(FilledBox)(({ theme, color }) => ({
    boxShadow: theme.boxShadows.moderate,
    backgroundColor: theme.colors[color],
}));
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const ColorBoxWrap = styled.div(_p => ({
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    width: '64px',
}));
const FlexWrap = styled.div(({ theme }) => ({
    display: 'flex',
    flexWrap: 'wrap',
    gap: theme.spacing.large,
}));
function Colors() {
    const theme = useTheme();
    const colors = Object.assign({}, theme.colors);
    delete colors.blue;
    delete colors.grey;
    delete colors.green;
    delete colors.yellow;
    delete colors.red;
    return (_jsx(FlexWrap, { children: Object.entries(colors).map(([key]) => (_jsxs(ColorBoxWrap, { children: [_jsx(ColorBox, { color: `${key}` }), _jsx(ItemLabel, { children: key })] }, key))) }));
}
const ShadowedBox = styled(FilledBox)(({ theme, shadow }) => ({ boxShadow: theme.boxShadows[shadow] }));
const ShadowsWrap = styled(FlexWrap)(({ theme }) => ({
    backgroundColor: theme.colors['fill-three'],
    padding: theme.spacing.large,
}));
function Shadows() {
    return (_jsx(ShadowsWrap, { children: ['slight', 'moderate', 'modal', 'focused'].map(key => (_jsxs(BlockWrapper, { children: [_jsx(ShadowedBox, { shadow: key }), _jsx(ItemLabel, { children: key })] }, key))) }));
}
const RadiusedBox = styled(FilledBox)(({ theme, radius }) => ({
    borderRadius: theme.borderRadiuses[radius],
}));
function BoxRadiuses() {
    const radii = ['medium', 'large'];
    return (_jsx(FlexWrap, { children: radii.map(key => (_jsxs(BlockWrapper, { children: [_jsx(RadiusedBox, { radius: key }), _jsx(ItemLabel, { children: key })] }, key))) }));
}
const BorderedBox = styled(RadiusedBox).attrs(() => ({ radius: 'medium' }))(({ theme, border }) => ({ border: theme.borders[border] }));
function BoxBorders() {
    const { borders } = useTheme();
    return (_jsx(FlexWrap, { children: Object.keys(borders).map(key => (_jsxs(BlockWrapper, { children: [_jsx(BorderedBox, { border: key }), _jsx(ItemLabel, { children: key })] }, key))) }));
}
const ScrollbarBox = styled(FilledBox)(({ theme, fillLevel }) => (Object.assign(Object.assign(Object.assign({}, theme.partials.scrollBar({ fillLevel })), theme.partials.text.caption), { backgroundColor: theme.colors[fillLevelToBGColor[fillLevel]], width: '100%', height: 'auto', padding: theme.spacing.medium, maxWidth: '300px', overflow: 'auto', '&.horizontal .inner': {
        width: '600px',
    }, '&.vertical': {
        maxHeight: '100px',
    }, '&.both': {
        maxHeight: '100px',
        '.inner': {
            width: '600px',
        },
    } })));
function Scrollbars() {
    const fillLevels = [0, 1, 2, 3];
    const exampleText = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.';
    return (_jsxs(_Fragment, { children: [_jsx(FlexWrap, { children: fillLevels.map(fillLevel => (_jsxs(BlockWrapper, { children: [_jsx(ScrollbarBox, Object.assign({ className: "vertical", fillLevel: fillLevel }, { children: _jsx("div", Object.assign({ className: "inner" }, { children: exampleText })) })), _jsxs(ItemLabel, { children: ["vertical - fillLevel=", fillLevel] })] }, fillLevel))) }), _jsx(FlexWrap, { children: fillLevels.map(fillLevel => (_jsxs(BlockWrapper, { children: [_jsx(ScrollbarBox, Object.assign({ className: "horizontal", fillLevel: fillLevel }, { children: _jsx("div", Object.assign({ className: "inner" }, { children: exampleText })) })), _jsxs(ItemLabel, { children: ["horizontal - fillLevel=", fillLevel] })] }, fillLevel))) }), _jsx(FlexWrap, { children: fillLevels.map(fillLevel => (_jsxs(BlockWrapper, { children: [_jsx(ScrollbarBox, Object.assign({ className: "both", fillLevel: fillLevel }, { children: _jsx("div", Object.assign({ className: "inner" }, { children: exampleText })) })), _jsxs(ItemLabel, { children: ["vertical + horizontal - fillLevel=", fillLevel] })] }, fillLevel))) })] }));
}
const SpacingBox = styled.div(({ theme, space }) => ({
    borderRadius: 0,
    backgroundColor: theme.colors['action-primary'],
    margin: 0,
    paddingRight: theme.spacing[space],
    paddingTop: theme.spacing[space],
    width: 'min-content',
}));
function Spacing() {
    return (_jsx(_Fragment, { children: [
            'xxxsmall',
            'xxsmall',
            'xsmall',
            'small',
            'medium',
            'large',
            'xlarge',
            'xxlarge',
            'xxxlarge',
            'xxxxlarge',
            'xxxxxlarge',
        ].map(key => (_jsxs(BlockWrapper, { children: [_jsx(SpacingBox, { space: key }), _jsx(ItemLabel, { children: key })] }, key))) }));
}
const SemanticText = styled.div(({ theme, typeStyle }) => (Object.assign(Object.assign({}, theme.partials.text[typeStyle]), { marginBottom: theme.spacing.large })));
function Typography({ exampleText: txt = 'Lorem ipsum dolor sit amet', }) {
    return (_jsxs(_Fragment, { children: [_jsxs(SemanticText, Object.assign({ typeStyle: "h1" }, { children: ["H1 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "h2" }, { children: ["H2 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "h3" }, { children: ["H3 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "h4" }, { children: ["H4 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "title1" }, { children: ["Title 1 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "title2" }, { children: ["Title 2 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "subtitle1" }, { children: ["Subtitle 1 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "subtitle2" }, { children: ["Subtitle 2 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "body1Bold" }, { children: ["Body 1 (Bold) - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "body1" }, { children: ["Body 1 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "body2Bold" }, { children: ["Body 2 (Bold) - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "body2" }, { children: ["Body 2 - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "body2LooseLineHeight" }, { children: ["Body 2 Loose Line Height - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "caption" }, { children: ["Caption - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "badgeLabel" }, { children: ["Badge Label - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "buttonLarge" }, { children: ["Large Button - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "buttonSmall" }, { children: ["Small Button - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "overline" }, { children: ["Overline - ", txt] })), _jsxs(SemanticText, Object.assign({ typeStyle: "code" }, { children: ["Code - ", txt] }))] }));
}
const MktgText = styled.div(({ theme, typeStyle }) => (Object.assign(Object.assign({}, theme.partials.marketingText[typeStyle]), { display: 'block', marginBottom: theme.spacing.large })));
const MarketingInlineLink = styled.a(({ theme }) => (Object.assign({}, theme.partials.marketingText.inlineLink)));
function MarketingTypography({ exampleText: txt = 'Lorem ipsum dolor sit amet', }) {
    return (_jsxs(_Fragment, { children: [_jsxs(MktgText, Object.assign({ typeStyle: "bigHeader" }, { children: ["Big Header (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "hero1" }, { children: ["Hero 1 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "hero2" }, { children: ["Hero 2 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "title1" }, { children: ["Title 1 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "title2" }, { children: ["Title 2 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "subtitle1" }, { children: ["Subtitle 1 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "subtitle2" }, { children: ["Subtitle 2 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "body1Bold" }, { children: ["Body 1 (Bold) (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "body1" }, { children: ["Body 1 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "body2Bold" }, { children: ["Body 2 (Bold) (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "body2" }, { children: ["Body 2 (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "standaloneLink" }, { children: ["Standalone link - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "componentText" }, { children: ["Component text (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "componentLink" }, { children: ["Component link - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "componentLinkSmall" }, { children: ["Small component link - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "label" }, { children: ["Label (", _jsx(MarketingInlineLink, Object.assign({ href: "#" }, { children: "Inline link" })), ") - ", txt] })), _jsxs(MktgText, Object.assign({ typeStyle: "navLink" }, { children: ["Nav link - ", txt] }))] }));
}
export const SemanticSystem = Template.bind({});
SemanticSystem.args = {
    exampleText: 'Lorem ipsum dolor sit amet',
};
//# sourceMappingURL=_SemanticSystem.stories.js.map